==> agconnect_appmessaging-1.3.0%2B300.tar.gz: lib/src/card_message.dart <==
// Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

part of agconnect_appmessaging;

class CardMessage {
  final String title;
  final String titleColor;
  final num titleColorOpenness;
  final String? body;
  final String bodyColor;
  final num bodyColorOpenness;
  final String backgroundColor;
  final num backgroundColorOpenness;
  final String portraitPictureUrl;
  final String landscapePictureUrl;
  final CardMessageButton majorButton;
  final CardMessageButton? minorButton;

  CardMessage._(Map<String, dynamic> map)
      : title = map['title'],
        titleColor = map['titleColor'],
        titleColorOpenness = map['titleColorOpenness'],
        body = map['body'],
        bodyColor = map['bodyColor'],
        bodyColorOpenness = map['bodyColorOpenness'],
        backgroundColor = map['backgroundColor'],
        backgroundColorOpenness = map['backgroundColorOpenness'],
        portraitPictureUrl = map['portraitPictureURL'],
        landscapePictureUrl = map['landscapePictureURL'],
        majorButton = CardMessageButton._(Map<String, dynamic>.from(map['majorButton'])),
        minorButton =
            map['minorButton'] == null ? null : CardMessageButton._(Map<String, dynamic>.from(map['minorButton']));

  @override
  String toString() {
    return '$CardMessage('
        'title: $title, '
        'titleColor: $titleColor, '
        'titleColorOpenness: $titleColorOpenness, '
        'body: $body, '
        'bodyColor: $bodyColor, '
        'bodyColorOpenness: $bodyColorOpenness, '
        'backgroundColor: $backgroundColor, '
        'backgroundColorOpenness: $backgroundColorOpenness, '
        'portraitPictureUrl: $portraitPictureUrl, '
        'landscapePictureUrl: $landscapePictureUrl, '
        'majorButton: $majorButton, '
        'minorButton: ${minorButton ?? 'null'})';
  }
}

==> agconnect_appmessaging-1.5.0%2B300.tar.gz: lib/src/card_message.dart <==
// Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

part of agconnect_appmessaging;

class CardMessage {
  final String title;
  final String titleColor;
  final num titleColorOpenness;
  final String? body;
  final String bodyColor;
  final num bodyColorOpenness;
  final String backgroundColor;
  final num backgroundColorOpenness;
  final String portraitPictureUrl;
  final String landscapePictureUrl;
  final CardMessageButton majorButton;
  final CardMessageButton? minorButton;

  CardMessage._(Map<String, dynamic> map)
      : title = map['title'],
        titleColor = map['titleColor'],
        titleColorOpenness = map['titleColorOpenness'],
        body = map['body'],
        bodyColor = map['bodyColor'],
        bodyColorOpenness = map['bodyColorOpenness'],
        backgroundColor = map['backgroundColor'],
        backgroundColorOpenness = map['backgroundColorOpenness'],
        portraitPictureUrl = map['portraitPictureURL'],
        landscapePictureUrl = map['landscapePictureURL'],
        majorButton =
            CardMessageButton._(Map<String, dynamic>.from(map['majorButton'])),
        minorButton = map['minorButton'] == null
            ? null
            : CardMessageButton._(
                Map<String, dynamic>.from(map['minorButton']));

  @override
  String toString() {
    return '$CardMessage('
        'title: $title, '
        'titleColor: $titleColor, '
        'titleColorOpenness: $titleColorOpenness, '
        'body: $body, '
        'bodyColor: $bodyColor, '
        'bodyColorOpenness: $bodyColorOpenness, '
        'backgroundColor: $backgroundColor, '
        'backgroundColorOpenness: $backgroundColorOpenness, '
        'portraitPictureUrl: $portraitPictureUrl, '
        'landscapePictureUrl: $landscapePictureUrl, '
        'majorButton: $majorButton, '
        'minorButton: ${minorButton ?? 'null'})';
  }
}
